@@ -15,6 +15,7 @@ import (
 	"github.com/superfly/flyctl/internal/command/deploy"
 	"github.com/superfly/flyctl/internal/command/launch/legacy"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flyerr"
 	"github.com/superfly/flyctl/iostreams"
 )
 
@@ -54,11 +55,6 @@ func New() (cmd *cobra.Command) {
 			Description: "Use the configuration file if present without prompting",
 			Default:     false,
 		},
-		flag.Bool{
-			Name:        "reuse-app",
-			Description: "Continue even if app name clashes with an existent app",
-			Default:     false,
-		},
 		flag.Bool{
 			Name:        "dockerignore-from-gitignore",
 			Description: "If a .dockerignore does not exist, create one from .gitignore files",
@@ -69,12 +65,6 @@ func New() (cmd *cobra.Command) {
 			Description: "Set internal_port for all services in the generated fly.toml",
 			Default:     -1,
 		},
-		// Launch V2
-		flag.Bool{
-			Name:        "ui",
-			Description: "Use the Launch V2 interface",
-			Hidden:      true,
-		},
 		flag.Bool{
 			Name:        "manifest",
 			Description: "Output the generated manifest to stdout",
@@ -85,6 +75,18 @@ func New() (cmd *cobra.Command) {
 			Description: "Path to a manifest file for Launch ('-' reads from stdin)",
 			Hidden:      true,
 		},
+		// legacy launch flags (deprecated)
+		flag.Bool{
+			Name:        "legacy",
+			Description: "Use the legacy CLI interface (deprecated)",
+			Hidden:      true,
+		},
+		flag.Bool{
+			Name:        "reuse-app",
+			Description: "Continue even if app name clashes with an existent app",
+			Default:     false,
+			Hidden:      true,
+		},
 	)
 
 	return
@@ -120,7 +122,9 @@ func getManifestArgument(ctx context.Context) (*LaunchManifest, error) {
 
 func run(ctx context.Context) (err error) {
 
-	if !flag.GetBool(ctx, "ui") {
+	// NOTE: We depend on legacy launcher behavior for Nomad support, which is needed for the MigrateToV2 tests
+	//       Once we rip out those tests, this can go with them.
+	if flag.GetBool(ctx, "legacy") || flag.GetBool(ctx, "force-nomad") {
 		return legacy.Run(ctx)
 	}
 
@@ -188,21 +192,23 @@ func run(ctx context.Context) (err error) {
 		summary,
 	)
 
-	confirm := false
-	prompt := &survey.Confirm{
-		Message: lo.Ternary(
-			incompleteLaunchManifest,
-			"Would you like to continue in the web UI?",
-			"Do you want to tweak these settings before proceeding?",
-		),
-	}
-	err = survey.AskOne(prompt, &confirm)
-	if err != nil {
-		// TODO(allison): This should probably not just return the error
-		return err
+	editInUi := false
+	if io.IsInteractive() {
+		prompt := &survey.Confirm{
+			Message: lo.Ternary(
+				incompleteLaunchManifest,
+				"Would you like to continue in the web UI?",
+				"Do you want to tweak these settings before proceeding?",
+			),
+		}
+		err = survey.AskOne(prompt, &editInUi)
+		if err != nil {
+			// TODO(allison): This should probably not just return the error
+			return err
+		}
 	}
 
-	if confirm {
+	if editInUi {
 		err = state.EditInWebUi(ctx)
 		if err != nil {
 			return err
@@ -237,7 +243,11 @@ func warnLegacyBehavior(ctx context.Context) error {
 	// TODO(Allison): We probably want to support re-configuring an existing app, but
 	// that is different from the launch-into behavior of reuse-app, which basically just deployed.
 	if flag.IsSpecified(ctx, "reuse-app") {
-		return errors.New("the --reuse-app flag is no longer supported. you are likely looking for 'fly deploy'")
+
+		return flyerr.GenericErr{
+			Err:     "the --reuse-app flag is no longer supported. you are likely looking for 'fly deploy'",
+			Suggest: "for now, you can use 'fly launch --legacy --reuse-app', but this will be removed in a future release",
+		}
 	}
 	return nil
 }
